@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -16,6 +16,13 @@ at the top-level directory.
  * October 15, 2003
  *
  */
+
+/*! \file
+ * \brief LU factorization from CGSTRF (CGSSV)
+ *
+ * \ingroup Example
+ */
+
 #include "slu_cdefs.h"
 
 int main(int argc, char *argv[])
@@ -23,7 +30,7 @@ int main(int argc, char *argv[])
     SuperMatrix A;
     NCformat *Astore;
     complex   *a;
-    int      *asub, *xa;
+    int_t    *asub, *xa;
     int      *perm_c; /* column permutation vector */
     int      *perm_r; /* row permutations from partial pivoting */
     SuperMatrix L;      /* factor L */
@@ -31,7 +38,8 @@ int main(int argc, char *argv[])
     SuperMatrix U;      /* factor U */
     NCformat *Ustore;
     SuperMatrix B;
-    int      nrhs, ldx, info, m, n, nnz;
+    int      nrhs, ldx, m, n;
+    int_t    nnz, info;
     complex   *xact, *rhs;
     mem_usage_t   mem_usage;
     superlu_options_t options;
@@ -61,7 +69,7 @@ int main(int argc, char *argv[])
 
     cCreate_CompCol_Matrix(&A, m, n, nnz, a, asub, xa, SLU_NC, SLU_C, SLU_GE);
     Astore = A.Store;
-    printf("Dimension %dx%d; # nonzeros %d\n", A.nrow, A.ncol, Astore->nnz);
+    printf("Dimension %dx%d; # nonzeros %d\n", (int)A.nrow, (int)A.ncol, (int)Astore->nnz);
     
     nrhs   = 1;
     if ( !(rhs = complexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhs[].");
@@ -71,8 +79,8 @@ int main(int argc, char *argv[])
     cGenXtrue(n, nrhs, xact, ldx);
     cFillRHS(options.Trans, nrhs, xact, ldx, &A, &B);
 
-    if ( !(perm_c = intMalloc(n)) ) ABORT("Malloc fails for perm_c[].");
-    if ( !(perm_r = intMalloc(m)) ) ABORT("Malloc fails for perm_r[].");
+    if ( !(perm_c = int32Malloc(n)) ) ABORT("Malloc fails for perm_c[].");
+    if ( !(perm_r = int32Malloc(m)) ) ABORT("Malloc fails for perm_r[].");
 
     /* Initialize the statistics variables. */
     StatInit(&stat);
@@ -83,15 +91,16 @@ int main(int argc, char *argv[])
 
 	/* This is how you could access the solution matrix. */
         complex *sol = (complex*) ((DNformat*) B.Store)->nzval; 
+        (void)sol;  // suppress unused variable warning
 
 	 /* Compute the infinity norm of the error. */
 	cinf_norm_error(nrhs, &B, xact);
 
 	Lstore = (SCformat *) L.Store;
 	Ustore = (NCformat *) U.Store;
-    	printf("No of nonzeros in factor L = %d\n", Lstore->nnz);
-    	printf("No of nonzeros in factor U = %d\n", Ustore->nnz);
-    	printf("No of nonzeros in L+U = %d\n", Lstore->nnz + Ustore->nnz - n);
+    	printf("No of nonzeros in factor L = %lld\n", (long long) Lstore->nnz);
+    	printf("No of nonzeros in factor U = %lld\n", (long long) Ustore->nnz);
+    	printf("No of nonzeros in L+U = %lld\n", (long long) Lstore->nnz + Ustore->nnz - n);
     	printf("FILL ratio = %.1f\n", (float)(Lstore->nnz + Ustore->nnz - n)/nnz);
 	
 	cQuerySpace(&L, &U, &mem_usage);
@@ -99,7 +108,7 @@ int main(int argc, char *argv[])
 	       mem_usage.for_lu/1e6, mem_usage.total_needed/1e6);
 	
     } else {
-	printf("cgssv() error returns INFO= %d\n", info);
+	printf("cgssv() error returns INFO= %lld\n", (long long)info);
 	if ( info <= n ) { /* factorization completes */
 	    cQuerySpace(&L, &U, &mem_usage);
 	    printf("L\\U MB %.3f\ttotal MB needed %.3f\n",
@@ -122,5 +131,6 @@ int main(int argc, char *argv[])
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Exit main()");
 #endif
+    return EXIT_SUCCESS;
 }
 
